@@ -4,10 +4,11 @@ import click
 from adbutils import adb
 from PySide6.QtGui import QImage, QKeyEvent, QMouseEvent, QPixmap
 from PySide6.QtWidgets import QApplication, QMainWindow
-from ui_main import Ui_MainWindow
 
 import scrcpy
 
+from .ui_main import Ui_MainWindow
+
 app = QApplication([])
 
 
